pub struct HttpsConnector<T> { /* private fields */ }
A Connector for the https scheme.

Implementations

Construct a new HttpsConnector.

Takes number of DNS worker threads.

This uses hyper’s default HttpConnector, and default TlsConnector. If you wish to use something besides the defaults, use From::from.

Note

By default this connector will use plain HTTP if the URL provded uses the HTTP scheme (eg: http://example.com/).

If you would like to force the use of HTTPS then call https_only(true) on the returned connector.

Force the use of HTTPS when connecting.

If a URL is not https when connecting, an error is returned.